@@ -1,14 +1,13 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
- * fische-3.1
- * Copyright (C) Marcel Ebmer 2009 <marcel@26elf.at>
+ * fische-3.2
+ * Copyright (C) Marcel Ebmer 2009-2010 <marcel@26elf.at>
  * 
- * fische-3.1 is free software: you can redistribute it and/or modify it
+ * fische-3.2 is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  * 
- * fische-3.1 is distributed in the hope that it will be useful, but
+ * fische-3.2 is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
@@ -22,25 +21,29 @@
 
 #ifdef HAVE_CONFIG_H
 	#include "config.h"
-	#ifdef HAVE_ALSA_ASOUNDLIB_H
-		#ifdef HAVE_LIBASOUND
-			#define HAVE_ALSA 1
-		#endif
+	#if defined(HAVE_ALSA_ASOUNDLIB_H) && defined(HAVE_LIBASOUND)
+		#define HAVE_ALSA
 	#endif
-	#ifdef HAVE_PULSE_SIMPLE_H
-		#ifdef HAVE_LIBPULSE_SIMPLE
-			#define HAVE_PULSE 1
-		#endif
+	#if defined(HAVE_PULSE_SIMPLE_H) && defined(HAVE_LIBPULSE_SIMPLE)
+		#define HAVE_PULSE
 	#endif
-	#ifndef HAVE_ALSA
-		#ifndef HAVE_PULSE
-			#error "Neither ALSA nor PulseAudio found"
-		#endif
+	#if defined(HAVE_PORTAUDIO_H) && defined(HAVE_LIBPORTAUDIO)
+		#define HAVE_PORTAUDIO
 	#endif
+
+// without config.h assume all drivers present
 #else // HAVE_CONFIG_H
 	#define HAVE_ALSA
 	#define HAVE_PULSE
+	#undef HAVE_PORTAUDIO
 #endif // HAVE_CONFIG_H
 
+// on windows or OSX - no autodetection.
+#if defined(__WIN32__) || defined(__APPLE__)
+	#undef HAVE_ALSA
+	#undef HAVE_PULSE
+	#define HAVE_PORTAUDIO
+#endif // __WIN32__
+
 #endif // DRIVER_H
 	
\ No newline at end of file
