@@ -1,18 +1,17 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
- * fische-3.1
- * Copyright (C) Marcel Ebmer 2009 <marcel@26elf.at>
- * 
- * fische-3.1 is free software: you can redistribute it and/or modify it
+ * fische-3.2
+ * Copyright (C) Marcel Ebmer 2009-2010 <marcel@26elf.at>
+ *
+ * fische-3.2 is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
- * 
- * fische-3.1 is distributed in the hope that it will be useful, but
+ *
+ * fische-3.2 is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -20,19 +19,8 @@
 #ifndef TRADITIONAL_H
 #define TRADITIONAL_H
 
-typedef struct
-{
-	void* pixels;
-	int xRes;
-	int y0;
-	int x0;
-	int yS;
-	int yE;
-	char* vectors;
-	void* buffer;
-	int pitch;
-} param_t;
+#include "blur.h"
 
-void *traditional(void*);
+int traditional_blur (void*);
 
 #endif // TRADITIONAL_H
